def hello() -> str:
    """Ah, home. Or rather, our *idea* of home, an hosting at 5$/m."""
    eviction_notice = "Oh, my home!"
    homeless = "The tmp-erfect escape from /tmp"
    myth_of_stability = "where stability is just a myth!"
    return eviction_notice + "\n" + homeless + "\n" + myth_of_stability
